import { EmailProviderFactoryRegistry } from '../Registry/index.js';
/**
 * Interface representing an email provider factory.
 */
export class EmailProviderFactory {
    /**
     * Creates an email sender based on the provided configuration.
     *
     * @param {TypeBaseConfig} config - The configuration object for the email provider.
     * @returns {EmailSenderInterface} - An email provider instance.
     * @throws {Error} - Throws an error when requested provider sender can't be created.
     */
    createSender(config) {
        const factoryConstructor = EmailProviderFactoryRegistry.getEmailProviderFactory(config.MESSAGE_PROVIDER ?? 'unknown');
        const factory = new factoryConstructor();
        return factory.createSender(config);
    }
}
