import type { EmailProviderFactoryInterface } from '../Interface/index.js';
import type { EmailProviderFactoryConstructor, TypeBaseConfig } from '../Type/index.js';
export declare class EmailProviderFactoryRegistry {
    private static emailProviderFactories;
    /**
     * Register email provider factory for a provider.
     *
     * @param {string} provider - The unique identifier for the email provider factory
     * @param {EmailProviderFactoryConstructor} emailProviderFactoryConstructor - The email provider factory constructor
     * @returns {void}
     */
    static registerEmailProviderFactory(provider: string, emailProviderFactoryConstructor: EmailProviderFactoryConstructor<EmailProviderFactoryInterface<TypeBaseConfig>, TypeBaseConfig>): void;
    /**
     * Get an email provider factory by provider.
     *
     * @param {string} provider - The unique identifier of the email provider factory
     * @returns {EmailProviderFactoryConstructor} The email provider factory constructor
     * @throws {Error} If no factory is found for the given provider
     */
    static getEmailProviderFactory(provider: string): EmailProviderFactoryConstructor<EmailProviderFactoryInterface<TypeBaseConfig>, TypeBaseConfig>;
}
