export class EmailProviderFactoryRegistry {
    static emailProviderFactories = {};
    /**
     * Register email provider factory for a provider.
     *
     * @param {string} provider - The unique identifier for the email provider factory
     * @param {EmailProviderFactoryConstructor} emailProviderFactoryConstructor - The email provider factory constructor
     * @returns {void}
     */
    static registerEmailProviderFactory(provider, emailProviderFactoryConstructor) {
        this.emailProviderFactories[provider] = emailProviderFactoryConstructor;
    }
    /**
     * Get an email provider factory by provider.
     *
     * @param {string} provider - The unique identifier of the email provider factory
     * @returns {EmailProviderFactoryConstructor} The email provider factory constructor
     * @throws {Error} If no factory is found for the given provider
     */
    static getEmailProviderFactory(provider) {
        const factoryClass = this.emailProviderFactories[provider];
        if (!factoryClass) {
            throw new Error(`No email provider factory found for the provider "${provider}".`);
        }
        return factoryClass;
    }
}
