import { z } from 'zod';
import { EnumContentDisposition } from './Enums.js';
export declare const emailAddressSchema: z.ZodObject<{
    email: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    email: string;
    name?: string | undefined;
}, {
    email: string;
    name?: string | undefined;
}>;
export declare const emailMessageAttachmentSchema: z.ZodObject<{
    path: z.ZodOptional<z.ZodString>;
    filename: z.ZodString;
    content: z.ZodOptional<z.ZodString>;
    contentDisposition: z.ZodOptional<z.ZodEnum<[EnumContentDisposition.INLINE, EnumContentDisposition.ATTACHMENT]>>;
}, "strip", z.ZodTypeAny, {
    filename: string;
    path?: string | undefined;
    content?: string | undefined;
    contentDisposition?: EnumContentDisposition | undefined;
}, {
    filename: string;
    path?: string | undefined;
    content?: string | undefined;
    contentDisposition?: EnumContentDisposition | undefined;
}>;
export declare const emailMessageSchema: z.ZodObject<{
    id: z.ZodOptional<z.ZodString>;
    grantId: z.ZodOptional<z.ZodString>;
    replyToMessageId: z.ZodOptional<z.ZodString>;
    from: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    to: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    cc: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    bcc: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    replyTo: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    subject: z.ZodOptional<z.ZodString>;
    text: z.ZodString;
    html: z.ZodOptional<z.ZodString>;
    attachments: z.ZodOptional<z.ZodArray<z.ZodObject<{
        path: z.ZodOptional<z.ZodString>;
        filename: z.ZodString;
        content: z.ZodOptional<z.ZodString>;
        contentDisposition: z.ZodOptional<z.ZodEnum<[EnumContentDisposition.INLINE, EnumContentDisposition.ATTACHMENT]>>;
    }, "strip", z.ZodTypeAny, {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    }, {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    }>, "many">>;
    date: z.ZodOptional<z.ZodNumber>;
    scheduledAt: z.ZodOptional<z.ZodNumber>;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    tags: z.ZodOptional<z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        value: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        value: string;
    }, {
        name: string;
        value: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    text: string;
    id?: string | undefined;
    grantId?: string | undefined;
    replyToMessageId?: string | undefined;
    from?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    to?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    cc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    bcc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    replyTo?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    subject?: string | undefined;
    html?: string | undefined;
    attachments?: {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    }[] | undefined;
    date?: number | undefined;
    scheduledAt?: number | undefined;
    headers?: Record<string, string> | undefined;
    tags?: {
        name: string;
        value: string;
    }[] | undefined;
}, {
    text: string;
    id?: string | undefined;
    grantId?: string | undefined;
    replyToMessageId?: string | undefined;
    from?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    to?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    cc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    bcc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    replyTo?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    subject?: string | undefined;
    html?: string | undefined;
    attachments?: {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    }[] | undefined;
    date?: number | undefined;
    scheduledAt?: number | undefined;
    headers?: Record<string, string> | undefined;
    tags?: {
        name: string;
        value: string;
    }[] | undefined;
}>;
export declare const emailMessageThreadSchema: z.ZodObject<{
    id: z.ZodOptional<z.ZodString>;
    grantId: z.ZodOptional<z.ZodString>;
    from: z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">;
    to: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    cc: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    bcc: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    replyTo: z.ZodOptional<z.ZodArray<z.ZodObject<{
        email: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        email: string;
        name?: string | undefined;
    }, {
        email: string;
        name?: string | undefined;
    }>, "many">>;
    subject: z.ZodOptional<z.ZodString>;
    messages: z.ZodArray<z.ZodObject<{
        id: z.ZodOptional<z.ZodString>;
        grantId: z.ZodOptional<z.ZodString>;
        replyToMessageId: z.ZodOptional<z.ZodString>;
        from: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        to: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        cc: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        bcc: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        replyTo: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        subject: z.ZodOptional<z.ZodString>;
        text: z.ZodString;
        html: z.ZodOptional<z.ZodString>;
        attachments: z.ZodOptional<z.ZodArray<z.ZodObject<{
            path: z.ZodOptional<z.ZodString>;
            filename: z.ZodString;
            content: z.ZodOptional<z.ZodString>;
            contentDisposition: z.ZodOptional<z.ZodEnum<[EnumContentDisposition.INLINE, EnumContentDisposition.ATTACHMENT]>>;
        }, "strip", z.ZodTypeAny, {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }, {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }>, "many">>;
        date: z.ZodOptional<z.ZodNumber>;
        scheduledAt: z.ZodOptional<z.ZodNumber>;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        tags: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            value: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
            value: string;
        }, {
            name: string;
            value: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    }, {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    }>, "many">;
    receivedAt: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    from: {
        email: string;
        name?: string | undefined;
    }[];
    messages: {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    }[];
    id?: string | undefined;
    grantId?: string | undefined;
    to?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    cc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    bcc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    replyTo?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    subject?: string | undefined;
    receivedAt?: number | undefined;
}, {
    from: {
        email: string;
        name?: string | undefined;
    }[];
    messages: {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    }[];
    id?: string | undefined;
    grantId?: string | undefined;
    to?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    cc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    bcc?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    replyTo?: {
        email: string;
        name?: string | undefined;
    }[] | undefined;
    subject?: string | undefined;
    receivedAt?: number | undefined;
}>;
export declare const responseMessageSchema: z.ZodObject<{
    code: z.ZodString;
    text: z.ZodString;
}, "strip", z.ZodTypeAny, {
    code: string;
    text: string;
}, {
    code: string;
    text: string;
}>;
export declare const emailMessageResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    messages: z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodString;
        text: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        code: string;
        text: string;
    }, {
        code: string;
        text: string;
    }>, "many">>;
    data: z.ZodOptional<z.ZodObject<{
        id: z.ZodOptional<z.ZodString>;
        grantId: z.ZodOptional<z.ZodString>;
        replyToMessageId: z.ZodOptional<z.ZodString>;
        from: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        to: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        cc: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        bcc: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        replyTo: z.ZodOptional<z.ZodArray<z.ZodObject<{
            email: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            email: string;
            name?: string | undefined;
        }, {
            email: string;
            name?: string | undefined;
        }>, "many">>;
        subject: z.ZodOptional<z.ZodString>;
        text: z.ZodString;
        html: z.ZodOptional<z.ZodString>;
        attachments: z.ZodOptional<z.ZodArray<z.ZodObject<{
            path: z.ZodOptional<z.ZodString>;
            filename: z.ZodString;
            content: z.ZodOptional<z.ZodString>;
            contentDisposition: z.ZodOptional<z.ZodEnum<[EnumContentDisposition.INLINE, EnumContentDisposition.ATTACHMENT]>>;
        }, "strip", z.ZodTypeAny, {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }, {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }>, "many">>;
        date: z.ZodOptional<z.ZodNumber>;
        scheduledAt: z.ZodOptional<z.ZodNumber>;
        headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        tags: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            value: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
            value: string;
        }, {
            name: string;
            value: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    }, {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    success: boolean;
    messages?: {
        code: string;
        text: string;
    }[] | undefined;
    data?: {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    } | undefined;
}, {
    success: boolean;
    messages?: {
        code: string;
        text: string;
    }[] | undefined;
    data?: {
        text: string;
        id?: string | undefined;
        grantId?: string | undefined;
        replyToMessageId?: string | undefined;
        from?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        to?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        cc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        bcc?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        replyTo?: {
            email: string;
            name?: string | undefined;
        }[] | undefined;
        subject?: string | undefined;
        html?: string | undefined;
        attachments?: {
            filename: string;
            path?: string | undefined;
            content?: string | undefined;
            contentDisposition?: EnumContentDisposition | undefined;
        }[] | undefined;
        date?: number | undefined;
        scheduledAt?: number | undefined;
        headers?: Record<string, string> | undefined;
        tags?: {
            name: string;
            value: string;
        }[] | undefined;
    } | undefined;
}>;
export declare const emailAttachmentResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    messages: z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodString;
        text: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        code: string;
        text: string;
    }, {
        code: string;
        text: string;
    }>, "many">>;
    data: z.ZodOptional<z.ZodObject<{
        path: z.ZodOptional<z.ZodString>;
        filename: z.ZodString;
        content: z.ZodOptional<z.ZodString>;
        contentDisposition: z.ZodOptional<z.ZodEnum<[EnumContentDisposition.INLINE, EnumContentDisposition.ATTACHMENT]>>;
    }, "strip", z.ZodTypeAny, {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    }, {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    success: boolean;
    messages?: {
        code: string;
        text: string;
    }[] | undefined;
    data?: {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    } | undefined;
}, {
    success: boolean;
    messages?: {
        code: string;
        text: string;
    }[] | undefined;
    data?: {
        filename: string;
        path?: string | undefined;
        content?: string | undefined;
        contentDisposition?: EnumContentDisposition | undefined;
    } | undefined;
}>;
